@@ -288,7 +288,7 @@ class dyn_obj:
 
                 tmp_curve_mesh = bpy.data.objects[self.name+'_streamline']
                 
-                bpy.context.scene.objects.active = tmp_curve_mesh
+                bpy.context.view_layer.objects.active = tmp_curve_mesh
                 self.streamline.select_set(state=True)
 
                 bpy.ops.object.join_shapes()
